expfit2(object, fitcyc = 5, plot = TRUE, pval = 0.01, ...)multdrc.outlier and studres for calculation of the studentized residuals and definition of the outlier cycles.
The efficiency is calculated a) from the exponential fit with $E = exp(d)$ (Eff.fit) and b) for each cycle within
the exponential region from the raw fluorescence values by $E = \frac{F(n)}{F(n-1)}$ (Eff.curve). The inital
template fluorescence (F0) is derived from parameter b. If the detection of outlier cycles is problematic (i.e. due to high noise), one can improve results by lowering the p-value.m <- multdrc(F1.1 ~ Cycles, data = reps, fct = l5())
expfit2(m)Run the code above in your browser using DataLab